//
//  VankeStatementListModel.m
//  vanke
//
//  Created by xiaomi on 15/10/8.
//  Copyright © 2015年 gomore. All rights reserved.
//

#import "VankeStatementListModel.h"

#undef	PER_PAGE
#define PER_PAGE	(10)

@implementation VankeStatementListModel

@synthesize settleEquals = _settleEquals;
@synthesize confirmed = _confirmed;
@synthesize projectsIn = _projectsIn;
@synthesize shopNameOrCodeLike = _shopNameOrCodeLike;
@synthesize items = _items;

- (void)load
{
    self.autoSave = YES;
    self.autoLoad = YES;
    self.items = [NSMutableArray array];
}

- (void)unload
{
    self.settleEquals = nil;
    self.confirmed = nil;
    self.projectsIn = nil;
    self.shopNameOrCodeLike = nil;
    self.items = nil;
}

#pragma mark - paging query

- (void)firstPage
{
    [self gotoPage:1];
}

- (void)nextPage
{
    if ( self.items.count )
    {
        [self gotoPage:(self.items.count / PER_PAGE + 1)];
    }
}

- (void)gotoPage:(NSUInteger)page {
    [VankeSettlementListAPI cancel];
    
    VankeSettlementListAPI *api = [VankeSettlementListAPI api];
    
    @weakify(api);
    @weakify(self);
    
    api.settleEquals = self.settleEquals;
    api.confirmed = self.confirmed;
    api.projectsIn = self.projectsIn;
    api.shopNameOrCodeLike = self.shopNameOrCodeLike;
    
    api.whenUpdate = ^
    {
        @normalize(api);
        @normalize(self);
        
        if ( api.sending )
        {
            [self sendUISignal:self.RELOADING];
        }
        else
        {
            if ( api.succeed )
            {
                StatementListResponse *resp = (StatementListResponse*) api.serverResp;
                if ( nil == resp || nil == resp.records )
                {
                    api.failed = YES;
                }
                else
                {
                    NSArray *records = resp.records;
                    StatementSummary *firstRecord = (StatementSummary*) [records objectAtIndex:0];
                    if ( page <= 1 )
                    {
                        [self.items removeAllObjects];
                        [self.items addObjectsFromArray:firstRecord.items];
                    }
                    else
                    {
                        [self.items addObjectsFromArray:firstRecord.items];
                        [self.items unique:^NSComparisonResult(id left, id right) {
                            return [((SubjectItem *)left).subject compare:((SubjectItem *)right).subject];
                        }];
                    }
                    
                    self.more = [resp hasMore];
                    self.loaded = YES;
                }
            }
                        
            [self sendUISignal:self.RELOADED];
        }
    };
    
    [api send];
}

@end
